@@ -36,6 +36,12 @@ class CacheReader:
         self._redis = await create_redis(str(self._url))
         self._ready = True
 
+    async def stop(self):
+        self.logger().info(f"Stopping cache reader redis connections.")
+        self._redis.close()
+        await self._redis.wait_closed()
+        self.logger().info(f"Finished stopping cache reader redis connection. ")
+
     async def read(self):
         try:
             return await self._redis.get(self._record_key)
