@@ -1,8 +1,11 @@
 import pendulum
 
 
-def give_me_time_in_iso(timestamp: float):
-    return pendulum.from_timestamp(timestamp).to_iso8601_string()
+def give_me_time_in_iso(timestamp: float, short: bool = False):
+    if not short:
+        return pendulum.from_timestamp(timestamp).to_iso8601_string()
+
+    return pendulum.from_timestamp(timestamp).to_time_string()
 
 
 def is_this_a_valid_datetime_string(alleged_date: str):
@@ -19,12 +22,15 @@ def give_me_a_timestamp_from_this_string(str_date: str):
     return pendulum.parse(str_date).timestamp()
 
 
-def the_time_in_iso_now_is():
-    return pendulum.now().to_iso8601_string()
+def the_time_in_iso_now_is(short: bool = False):
+    if not short:
+        return pendulum.now('UTC').to_iso8601_string()
+
+    return pendulum.now('UTC').to_time_string()
 
 
 def the_time_now_is() -> float:
-    return pendulum.now().timestamp()
+    return pendulum.now('UTC').timestamp()
 
 
 def go_back_in_time(time_to_reduce: float, seconds_to_reduce: int):
